==> openshift-model-whereabouts-6.7.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OverlappingRangeIPReservationBuilder extends OverlappingRangeIPReservationFluentImpl<OverlappingRangeIPReservationBuilder> implements VisitableBuilder<OverlappingRangeIPReservation,OverlappingRangeIPReservationBuilder>{
  public OverlappingRangeIPReservationBuilder() {
    this(false);
  }
  public OverlappingRangeIPReservationBuilder(Boolean validationEnabled) {
    this(new OverlappingRangeIPReservation(), validationEnabled);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent) {
    this(fluent, false);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OverlappingRangeIPReservation(), validationEnabled);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent,OverlappingRangeIPReservation instance) {
    this(fluent, instance, false);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent,OverlappingRangeIPReservation instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservation instance) {
    this(instance,false);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservation instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OverlappingRangeIPReservationFluent<?> fluent;
  Boolean validationEnabled;
  public OverlappingRangeIPReservation build() {
    OverlappingRangeIPReservation buildable = new OverlappingRangeIPReservation(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-whereabouts-6.8.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OverlappingRangeIPReservationBuilder extends OverlappingRangeIPReservationFluent<OverlappingRangeIPReservationBuilder> implements VisitableBuilder<OverlappingRangeIPReservation,OverlappingRangeIPReservationBuilder>{
  public OverlappingRangeIPReservationBuilder() {
    this(false);
  }
  public OverlappingRangeIPReservationBuilder(Boolean validationEnabled) {
    this(new OverlappingRangeIPReservation(), validationEnabled);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent) {
    this(fluent, false);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OverlappingRangeIPReservation(), validationEnabled);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent,OverlappingRangeIPReservation instance) {
    this(fluent, instance, false);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservationFluent<?> fluent,OverlappingRangeIPReservation instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new OverlappingRangeIPReservation());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservation instance) {
    this(instance,false);
  }
  public OverlappingRangeIPReservationBuilder(OverlappingRangeIPReservation instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new OverlappingRangeIPReservation());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OverlappingRangeIPReservationFluent<?> fluent;
  Boolean validationEnabled;
  public OverlappingRangeIPReservation build() {
    OverlappingRangeIPReservation buildable = new OverlappingRangeIPReservation(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
